@@ -29,6 +29,10 @@ class FilterError(MongoDBQueriesManagerBaseError):
     """ Raised when parse filter method fail to find a valid match. """
 
 
+class TextOperatorError(MongoDBQueriesManagerBaseError):
+    """ Raised when parse text operator contain an empty string. """
+
+
 class CustomCasterFail(MongoDBQueriesManagerBaseError):
     """ Raised when a custom cast fail. """
 
@@ -101,10 +105,15 @@ class MongoDBQueriesManager:
 
         # $in, $nin, $exists logic
         if isinstance(value, list):
+            # Cast list items
+            casted_list_item = list()
+            for item in value:
+                casted_list_item.append(self.cast_value_logic(item))
+
             if operator == '=':
-                return {key: {"$in": value}}
+                return {key: {"$in": casted_list_item}}
             if operator == '!=':
-                return {key: {"$nin": value}}
+                return {key: {"$nin": casted_list_item}}
             raise ListOperatorError('List operator not found')
 
         # $exists logic
@@ -184,6 +193,20 @@ class MongoDBQueriesManager:
             return sort_params_final
         return None
 
+    def text_operator_logic(self, text_param: str) -> str:
+        """ Convert text query value into MongoDB format
+
+        Args:
+            text_param (str): Text param from url query (ie, '$text=java shop -coffee')
+
+        Returns:
+            int: Limit integer value
+        """
+        if text_param == "$text=":
+            raise TextOperatorError('Bad $text value')
+
+        return self.cast_value_logic(text_param.split('=')[1])
+
     @staticmethod
     def limit_logic(limit_param: str) -> int:
         """ Convert query limit value into MongoDB format
